@@ -152,10 +152,5 @@ def stack(process_func):
 
 
 if __name__ == "__main__":
-    # Run doctest from __main__ and unittest from tests
-    from tests.unit_timeside import run_test_module
-    # load corresponding tests
-    from tests import test_decoder_utils
-
-    run_test_module(test_decoder_utils)
-
+    import doctest
+    doctest.testmod()
